# Taiwan Day Off API Wrapper

---
## Introduction
This is a simple API wrapper for Taiwan Day Off API. It provides a simple way to get the day off information in Taiwan.

---
## Installation
```bash
pip install taiwan_day_off
```
---
## Usage
```python
from taiwan_day_off import TaiwanDayOff
day_off_obj = TaiwanDayOff("Chinese City Or County Name")
print(day_off_obj.get_day_off())
```
---
## Welcome to contribute to this project
If you have any idea or suggestion, please feel free to open an issue or pull request.
---
## Thanks to all contributors
Below is the contributors of this project. Thanks for your contribution.</br>
<a href="https://github.com/Neko-no-akuma-TW/tw-dayoff/graphs/contributors">
<img src="https://contrib.rocks/image?repo=Neko-no-akuma-TW/tw-dayoff" />
</a>
